@@ -5,6 +5,6 @@
 
 
 from ThesisAZsc import preprocessing
-from ThesisAZsc import Load_Model
-from ThesisAZsc import predict
+from ThesisAZsc import Model_Selection
+from ThesisAZsc import PredictionModule
 
